% chisquare_ex1 - create the bar chart and do the chi-square test for the
% data in GoStats example data file

% See Figure 6.22b & Figure 6.25 in HCIERP2e

clear; clc;
close all;

path = '.';
fileName = 'chisquare-ex1';
fileExt = '.txt';

inputDataFile = fullfile(path, [fileName, fileExt]);
M = readmatrix(inputDataFile);

% do chi-square test using Scott's MATLAB function
[chi2, df, p, ~] = chi2test(M, 'off');

% output results (including observed counts in M)

outFile = strcat(fileName, '_output.txt');
if isfile(outFile)
    delete(outFile);
end
diary(outFile)

M
fprintf('chisquare = %.3f, df = %d, p = %.3f\n', chi2, df, p);
diary off

% ----------------
% create bar chart
% ----------------

barColor = [224, 177, 229; 144, 211, 209; 222, 233, 155] / 255;

f = figure;
set(f, 'color', 'w', 'units', 'normalized', 'position', [.2 .3 .3 .45]);

b = bar(M);
ax = gca;
ax.FontSize = 12;
ax.XLabel.String = 'Gender';
% ax.XLabel.FontWeight = 'bold';
ax.XLabel.FontSize = 14;
ax.XTickLabel = {'Male' 'Female'};

ax.YLabel.String = 'Number of Users';
% ax.YLabel.FontWeight = 'bold';
ax.YLabel.FontSize = 14;
ax.YGrid = 'on';

for i=1:length(b)
    b(i).BarWidth = 0.8;
    b(i).FaceColor = barColor(i,:);
    b(i).LineWidth = 1;
end

h = legend({'Mouse Wheel', 'Clicking or Dragging', 'Keyboard'});
h.Title.String = 'Scrolling Method';
h.Title.FontWeight = "normal";

xData = [1 2];

x1 = [b(1).XEndPoints, b(2).XEndPoints, b(3).XEndPoints];
y1 = M(:);
s = compose('%d', M(:));
text(x1, y1/2, s, 'horiz', 'center', 'fontsize', 12);

exportgraphics(f, [fileName, '.png'], 'Resolution',600);

% save directly in texlive images folder with 2e working filename
% path = 'C:\Users\mack\Desktop\Scott-new\Book2ndEdition\TeXlive_HCI_ERP2\images\';
% file = 'ch6-2ed-22b.png';
% exportgraphics(f, [path file], 'Resolution',600);

shg;

% *** end ***