% chisquare_ex2 - create the bar chart and do the chi-square test for the
% data in the example data file

% See Figure 6.27 in HCIERP2e

clear; clc;
close all;

path = '.';
fileName = 'chisquare-ex2';
fileExt = '.txt';

inputDataFile = fullfile(path, [fileName, fileExt]);
M = readmatrix(inputDataFile);

% do chi-square test using Scott's MATLAB function
[chi2, df, p, phTable] = chi2test(M, 'on');

% output results (including observed counts in M)
outFile = strcat(fileName, '_output.txt');
if isfile(outFile)
    delete(outFile);
end
diary(outFile)

M
fprintf('chisquare = %.3f, df = %d, p = %.3f\n', chi2, df, p);
fprintf('\n%s\n', phTable);
diary off

% ----------------
% create bar chart
% ----------------

barColor = [224, 177, 229; 144, 211, 209; 222, 233, 155] / 255;

f = figure;
set(f, 'color', 'w', 'units', 'normalized', 'position', [.2 .3 .3 .45]);

b = bar(M);
ax = gca;
ax.FontSize = 12;
ax.XLabel.String = 'Opinion';
% ax.XLabel.FontWeight = 'bold';
ax.XLabel.FontSize = 14;
ax.XTickLabel = {'Agree' 'Disagree'};

ax.YLim = [0 150];
ax.YTick = 0:20:150;
ax.YTickLabels = compose('%d', 0:20:150);

ax.YLabel.String = 'Number of Responses';
% ax.YLabel.FontWeight = 'bold';
ax.YLabel.FontSize = 14;
ax.YGrid = 'on';

for i=1:length(b)
    b(i).BarWidth = 1;
    b(i).FaceColor = barColor(i,:);
    b(i).LineWidth = .8;
end

h = legend({'Student', 'Professor', 'Parent'}, 'Location','northwest');
h.Title.String = 'Category of Person';
h.Title.FontWeight = "normal";

xData = [1 2];

x1 = [b(1).XEndPoints, b(2).XEndPoints, b(3).XEndPoints];
y1 = M(:);
s = compose('%d', M(:));
text(x1, y1/2, s, 'horiz', 'center', 'fontsize', 12);

exportgraphics(f, [fileName, '.png']);

% *** end ***