% lilliefors_ex1 - do the Lilliefors test for the data in the example data
% file

% See Figure 6.29 in HCIERP2e

clear; clc;
close all;

path = '.';
fileName = 'lilliefors-ex1';
fileExt = '.txt';

inputDataFile = fullfile(path, [fileName, fileExt]);

data = readmatrix(inputDataFile);

% using Scott's lilliefors function
[m, cv, f] = lilliefors(data, 'on');

% using MATLAB's lillietest function (Note: cv is a bit different)
%[~, ~, m, cv] = lillietest(data);

decisionArray = ["REJECTED" "NOT_REJECTED"];
decisionIdx = 1 + (m < cv);
decision = decisionArray(decisionIdx);

% --------------------------------
% generate output (as per GoStats)
% --------------------------------

outFile = strcat(fileName, '_output.txt');
if isfile(outFile)
    delete(outFile);
end
diary(outFile)

s = sprintf('%d, ', data);
s(end-1:end) = []; % remove trailing comma and space
fprintf('%s', s);
fprintf('\n');
fprintf('%4s = %9.5f\n', 'Mean', mean(data));
fprintf('%4s = %9.5f\n', 'SD', std(data));
fprintf('%4s = %9.5f (test statistic)\n', 'M', m);
fprintf('%4s = %9.5f (critical value)\n', 'CV', cv);
fprintf('Null hypothesis of normality is %s\n', decision);
diary off

% save graph in .png file (if displayopt = 'on')
if ~isempty(f)
    exportgraphics(f, [fileName, '.png']);
end

% *** end ***