% lilliefors_ex2 - do the lilliefors test for the data in the example data
% file

% See Figure 6.31 & Figure 6.32 in HCIERP2e

clear; clc;
close all;

path = '.';
fileName = 'lilliefors-ex2';
fileExt = '.txt';

inputDataFile = fullfile(path, [fileName, fileExt]);

data = readmatrix(inputDataFile);

% using Scott's lilliefors function
[m, cv, f] = lilliefors(data, 'on');

% using MATLAB's lillietest function (Note: cv is a bit different)
%[~, ~, m, cv] = lillietest(data);

decisionArray = ["REJECTED" "NOT_REJECTED"];
decisionIdx = 1 + (m < cv);
decision = decisionArray(decisionIdx);

% --------------------------------
% generate output (as per GoStats)
% --------------------------------

outFile = strcat(fileName, '_output.txt');
if isfile(outFile)
    delete(outFile);
end
diary(outFile)

s = sprintf('%.1f, ', data);
s(end-1:end) = []; % remove trailing comma and space
fprintf('%s', s);
fprintf('\n');
fprintf('%4s = %9.5f\n', 'Mean', mean(data));
fprintf('%4s = %9.5f\n', 'SD', std(data));
fprintf('%4s = %9.5f (test statistic)\n', 'M', m);
fprintf('%4s = %9.5f (critical value)\n', 'CV', cv);
fprintf('Null hypothesis of normality is %s\n', decision);
diary off

% save graph in .png file (if displayopt = 'on')
if ~isempty(f)
    exportgraphics(f, [fileName, '.png'], 'Resolution',600);
end

% save directly in texlive images folder with 2e working filename
% path = '.';
% file = 'ch6-2e-23.png';
% exportgraphics(f, [path file], 'Resolution',600);

% save directly in texlive images folder with 2e working filename
% path = 'C:\Users\mack\Desktop\Scott-new\Book2ndEdition\TeXlive_HCI_ERP2\images\';
% file = 'ch6-2ed-32.png';
% exportgraphics(f, [path file], 'Resolution',600);

shg;

% *** end ***